@@ -32,8 +32,8 @@ class Coverage(Plugin):
     coverTests = False
     coverPackages = None
     
-    def add_options(self, parser, env=os.environ):
-        Plugin.add_options(self, parser, env)
+    def options(self, parser, env=os.environ):
+        Plugin.options(self, parser, env)
         parser.add_option("--cover-package", action="append",
                           default=env.get('NOSE_COVER_PACKAGE'),
                           dest="cover_packages",
@@ -92,8 +92,6 @@ class Coverage(Plugin):
         log.debug("Coverage report")
         import coverage
         coverage.stop()
-        coverage.the_coverage.save()
-        
         modules = [ module
                     for name, module in sys.modules.items()
                     if self.wantModuleCoverage(name, module) ]
@@ -126,10 +124,11 @@ class Coverage(Plugin):
         # coverPackages is on -- in that case, if we wanted this
         # module, we would have already returned True
         return not self.coverPackages
-    
+
     def wantFile(self, file, package=None):    
         """If inclusive coverage enabled, return true for all source files 
-        in wanted packages."""    
+        in wanted packages.
+        """
         if self.coverInclusive:
             if file.endswith(".py"): 
                 if package and self.coverPackages:
