@@ -21,23 +21,26 @@ class Profile(Plugin):
     """
     Use this plugin to run tests using the hotshot profiler. 
     """
-    def add_options(self, parser, env=os.environ):
-        Plugin.add_options(self, parser, env)                
-        parser.add_option('--profile-sort',action='store',dest='profile_sort',
-                          default=env.get('NOSE_PROFILE_SORT','cumulative'),
+    pfile = None
+    clean_stats_file = False
+    def options(self, parser, env=os.environ):
+        Plugin.options(self, parser, env)                
+        parser.add_option('--profile-sort', action='store', dest='profile_sort',
+                          default=env.get('NOSE_PROFILE_SORT', 'cumulative'),
                           help="Set sort order for profiler output")
-        parser.add_option('--profile-stats-file',action='store',
+        parser.add_option('--profile-stats-file', action='store',
                           dest='profile_stats_file',
                           default=env.get('NOSE_PROFILE_STATS_FILE'),
                           help='Profiler stats file; default is a new '
                           'temp file on each run')
-        parser.add_option('--profile-restrict',action='append',
+        parser.add_option('--profile-restrict', action='append',
                           dest='profile_restrict',
                           default=env.get('NOSE_PROFILE_RESTRICT'),
                           help="Restrict profiler output. See help for "
                           "pstats.Stats for details")
     
     def begin(self):
+        self._create_pfile()
         self.prof = hotshot.Profile(self.pfile)
 
     def configure(self, options, conf):
@@ -47,18 +50,18 @@ class Profile(Plugin):
 
         if options.profile_stats_file:
             self.pfile = options.profile_stats_file
+            self.clean_stats_file = False
         else:
-            fileno, filename = tempfile.mkstemp()
-            # close the open handle immediately, hotshot needs to open
-            # the file itself
-            os.close(fileno)
-            self.pfile = filename
+            self.pfile = None
+            self.clean_stats_file = True
+        self.fileno = None
         self.sort = options.profile_sort
         self.restrict = tolist(options.profile_restrict)
             
     def prepareTest(self, test):
         log.debug('preparing test %s' % test)
         def run_and_profile(result, prof=self.prof, test=test):
+            self._create_pfile()
             prof.runcall(test, result)
         return run_and_profile
         
@@ -77,3 +80,25 @@ class Profile(Plugin):
                 stats.print_stats()
         finally:
             sys.stdout = tmp
+
+    def finalize(self, result):
+        try:
+            self.prof.close()
+        except AttributeError:
+            pass
+        if self.clean_stats_file:
+            if self.fileno:
+                try:
+                    os.close(self.fileno)
+                except OSError:
+                    pass
+            try:
+                os.unlink(self.pfile)
+            except OSError:
+                pass
+        return None
+
+    def _create_pfile(self):
+        if not self.pfile:
+            self.fileno, self.pfile = tempfile.mkstemp()
+            self.clean_stats_file = True
